%global __requires_exclude perl\\(lib.pl\\)

Summary:        MariaDB and MySQL driver for the Perl5 Database Interface (DBI)
Name:           perl-DBD-MariaDB
Version:        1.22
Release:        6%{?dist}
License:        GPL+ or Artistic
URL:            https://metacpan.org/release/DBD-MariaDB/
Source0:        https://cpan.metacpan.org/authors/id/P/PA/PALI/DBD-MariaDB-%{version}.tar.gz
Source1:        test-setup.t
Source2:        test-clean.t
Source3:        test-env.sh
Patch3000:      DBD-MariaDB-1.21-Run-test-setup-and-clean.patch

BuildRequires:  make gcc
BuildRequires:  findutils openssl-devel hostname
BuildRequires:  mariadb mariadb-server mariadb-connector-c mariadb-connector-c-devel
BuildRequires:  perl-devel perl-generators perl-interpreter perl(strict) perl(warnings)
BuildRequires:  perl(:VERSION) >= 5.8.1 perl(Config) perl(FindBin) perl(lib) perl(constant)
BuildRequires:  perl(Data::Dumper) perl(DBI) >= 1.608 perl(DBI::DBD) perl(DBI::Const::GetInfoType)
BuildRequires:  perl(Devel::CheckLib) >= 1.12 perl(DynaLoader) perl(ExtUtils::MakeMaker) >= 6.76
BuildRequires:  perl(File::Spec) perl(File::Path) perl(File::Temp) perl(utf8) perl(Encode)
BuildRequires:  perl(B) perl(bigint) perl(Getopt::Long) perl(CPAN::Meta::YAML)
BuildRequires:  perl(Test::Deep) perl(Test::More) >= 0.90 perl(Time::HiRes) perl(vars)

%description
This module provides the Perl5 Database Interface driver for MariaDB and MySQL databases. In 
other words, DBD::MariaDB provides an interface between the Perl programming language and the 
MariaDB/MySQL programming API that acts on the MariaDB/MySQL relational database management system. 

%package tests
Summary:        Tests for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       perl-Test-Harness
Requires:       hostname
Requires:       mariadb
Requires:       mariadb-server
Requires:       perl(CPAN::Meta::YAML)

%description tests
Tests from %{name}. Execute them
with "%{_libexecdir}/%{name}/test".

%prep
%autosetup -p1 -n DBD-MariaDB-%{version}
cp %{SOURCE1} %{SOURCE2} t/

for F in t/*.t t/*.pl; do
    perl -i -MConfig -ple 'print $Config{startperl} if $. == 1 && !s{\A#!.*perl\b}{$Config{startperl}}' "$F"
    chmod +x "$F"
done

for F in t/pod.t t/manifest.t; do
    rm "$F"
    perl -i -ne 'print $_ unless m{^\Q'"$F"'\E}' MANIFEST
    perl -i -ne 'print $_ unless m{\Q'"$F"'\E}' t/testrules.yml
done

for F in t/60leaks.t t/rt86153-reconnect-fail-memory.t; do
    rm "$F"
    perl -i -ne 'print $_ unless m{^\Q'"$F"'\E}' MANIFEST
    perl -i -ne 'print $_ unless m{\Q'"$F"'\E}' t/testrules.yml
done

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="$RPM_OPT_FLAGS" NO_PACKLIST=1 NO_PERLLOCAL=1
%{make_build}

%install
%{make_install}
find %{buildroot} -type f -name '*.bs' -size 0 -delete

mkdir -p %{buildroot}%{_libexecdir}/%{name}
cp -a t %{buildroot}%{_libexecdir}/%{name}
cp %{SOURCE3} %{buildroot}%{_libexecdir}/%{name}
cat > %{buildroot}%{_libexecdir}/%{name}/test << EOF
#!/bin/sh
unset RELEASE_TESTING
. %{_libexecdir}/%{name}/$(basename %{SOURCE3})
cd %{_libexecdir}/%{name} && exec prove -I .
EOF
chmod +x %{buildroot}%{_libexecdir}/%{name}/test

%{_fixperms} %{buildroot}/*

%check
. %{SOURCE3}

make test 

%files
%license LICENSE
%doc Changes Changes.historic
%{perl_vendorarch}/auto/*
%{perl_vendorarch}/DBD*
%{_mandir}/man3/*

%files tests
%{_libexecdir}/%{name}

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.22-6
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Aug 18 2023 Wang Guodong <gordonwwang@tencent.com> - 1.22-5
- Rebuilt for mariadb-connector-c 3.3.5

* Tue Aug 15 2023 Xiaojie Chen <jackxjchen@tencent.com> - 1.22-4
- Remove perl(:MODULE_COMPAT) which will be generated by perl-generators >= 1.15

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.22-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.22-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Dec 15 2022 Wang Guodong <gordonwwang@tencent.com> - 1.22-1
- package init.
